@@ -1,3 +1,12 @@
+/*
+ * Test suite for libwebauth Kerberos TGT manipulation.
+ *
+ * Written by Roland Schemers
+ * Copyright 2003, 2006, 2009
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include "config.h"
 
@@ -11,7 +20,7 @@
 #include <string.h>
 #endif
 
-#include "webauth.h"
+#include <lib/webauth.h>
 #include "webauthtest.h"
 
 #define BUFSIZE 4096
